@@ -154,14 +154,15 @@ class DTestOutput(object):
         # Flush the output
         self.output.flush()
 
-    def result(self, result):
+    def result(self, result, debug=False):
         """
         Called at the end of a test run to emit ``result`` information
         for a given test.  Called once for each result.  Should emit
         all exception and captured output information, if any.  Will
         also be called for results from test fixtures, in order to
         emit errors encountered while executing them.  The default
-        implementation ignores results containing no messages.
+        implementation ignores results containing no messages, and
+        only emits results from successful tests if debug is True.
         """
 
         # Helper for reporting output
@@ -193,6 +194,11 @@ class DTestOutput(object):
         if len(result) == 0:
             return
 
+        # If it's successful or an expected failure, only emit
+        # messages if debug is True
+        if not debug and (result.state == OK or result.state == XFAIL):
+            return
+
         # Emit a banner for the result
         print >>self.output, ("\n" + ("=" * self.linewidth) + "\n" +
                               str(result.test).center(self.linewidth) + "\n" +
@@ -628,7 +634,13 @@ class DTestQueue(object):
             elif r.state == XFAIL:
                 cnt[FAIL] += int(r.test)
 
-            self.output.result(r)
+            try:
+                # Emit the result messages
+                self.output.result(r, debug)
+            except TypeError:
+                # Maybe the output object is written to the older
+                # standard?
+                self.output.result(r)
 
         # Emit summary data
         self.output.summary(cnt)
@@ -640,8 +652,11 @@ class DTestQueue(object):
         # We're done running; re-running should be legal
         self.running = False
 
-        # Return False if there were any unexpected failures or errors
-        if cnt[FAIL] > 0 or cnt[ERROR] > 0 or cnt[DEPFAIL] > 0:
+        # Return False if there were any unexpected OKs, unexpected
+        # failures, errors, or dependency failures
+        if (cnt[UOK] > 0 or
+            (cnt[FAIL] - cnt[XFAIL]) > 0 or
+            cnt[ERROR] > 0 or cnt[DEPFAIL] > 0):
             return False
 
         # All tests passed!
@@ -928,7 +943,8 @@ def main(directory=None, maxth=None, skip=lambda dt: dt.skip,
     ``skip``, and ``output`` (see the documentation for the run()
     function for more information on these three parameters).  Returns
     True if all tests (with the exclusion of expected failures)
-    passed, False if a failure or error was encountered.
+    passed, or False if an unexpect OK, a failure, or an error was
+    encountered.
     """
 
     # First, allocate a queue
@@ -1062,4 +1078,4 @@ if __name__ == '__main__':
     (options, args) = opts.parse_args()
 
     # Execute the test suite
-    sys.exit(main(**opts_to_args(options)))
+    sys.exit(not main(**opts_to_args(options)))
